/* CSS for the mobile version of the content server webpage */

body {
    font-family: sans-serif;
    background-color: #f6f3e9;
}

.body {
    font-family: sans-serif;
}

.navigation table.buttons {
    width: 100%;
}

.navigation .button {
    width: 50%;
}

.button a, .button:visited a {
    padding: 0.5em;
    font-size: larger;
    border: 1px solid black;
    color: #f6f3e9;
    text-decoration: none;
    margin-right: 0.5em;
    background-color: #39322b;
    border-top: 1px solid ThreeDLightShadow;
    border-right: 1px solid ButtonShadow;
    border-bottom: 1px solid ButtonShadow;
    border-left: 1 px solid ThreeDLightShadow;
    border-radius: 0.25em;
    -moz-border-radius: 0.25em;
    -webkit-border-radius: 0.25em;
}

.button:hover a {
    border-top: 1px solid #666;
    border-right: 1px solid #CCC;
    border-bottom: 1 px solid #CCC;
    border-left: 1 px solid #666;


}

div.navigation {
    padding-bottom: 1em;
    clear: both;
}

#search_box {
    border: 1px solid #393;
    border-radius: 0.5em;
    -moz-border-radius: 0.5em;
    -webkit-border-radius: 0.5em;
    padding: 1em;
    margin-bottom: 0.5em;
    float: right;
}

#listing {
    width: 100%;
    border-collapse: collapse;
}
#listing td {
    padding: 0.25em;
    vertical-align: middle;
}

#listing td.thumbnail {
    height: 60px;
    width: 60px;
}

#listing tr:nth-child(even) {

    background: #eee;
}

#listing .button a{
    display: inline-block;
    width: 2.5em;
    padding-left: 0em;
    padding-right: 0em;
    overflow: hidden;
    text-align: center;
    text-decoration: none;
    vertical-align: middle;
}

#logo {
    float: left;
}

#spacer {
    clear: both;
}

.data-container {
    display: inline-block;
    vertical-align: middle;
}

.first-line {
    font-size: larger;
    font-weight: bold;
}

.second-line {
    margin-top: 0.75ex;
    display: block;
}
